% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/extract.R
\name{extract}
\alias{extract}
\title{Extractor function for MixtureMissing}
\usage{
extract(
  object,
  what = c("model", "parameters", "cluster", "posterior", "outlier", "missing",
    "imputed", "complete", "information"),
  criterion = c("AIC", "BIC", "KIC", "KICc", "AIC3", "CAIC", "AICc", "ICL", "AWE", "CLC"),
  m_code = NULL
)
}
\arguments{
\item{object}{A \code{MixtureMissing} object or an output of \link{select_mixture}.}

\item{what}{The specific value to be extracted. See the return section for possible
values.}

\item{criterion}{If \code{what = "information"}, \code{criterion} is a vector of
desired information criteria. All criteria will be extracted by default. Duplicate values
in the vector will not be shown again. See the details section for a list of available
information criteria.}

\item{m_code}{Only used in the case when \code{object} is an output of \link{select_mixture}.
If \code{m_code = NULL}, extracting will be based on the best model. If \code{m_code} is one of 'CN', 'GH',
'NIG', 'SNIG', 'SC', 'C', 'St', 't', 'N', 'SGH', 'HUM', 'H', and 'SH', the function will look
for this specific model and extract accordingly.}
}
\value{
One of the following depending on \code{what}
\itemize{
  \item If \code{what = "model"} - A data frame showing the component distribution
    and its abbreviation, number of clusters, and whether the data set is complete
    or incomplete.
  \item If \code{what = "parameters"} - A list containing the relevant parameters.
  \item If \code{what = "cluster"} - A numeric vector of length \eqn{n} indicating cluster
    memberships determined by the model.
  \item If \code{what = "posterior"} - An \eqn{n} by \eqn{G} matrix where each
    row indicates the expected probabilities that the corresponding observation
    belongs to each cluster.
  \item If \code{what = "outlier"} - A logical vector of length \eqn{n} indicating observations that are outliers.
    Only available if \code{model} is CN or t; NULL otherwise with a warning.
  \item If \code{what = "missing"} - A data frame showing how many observations (cases)
    have missing values and the number of missing values per variables.
  \item If \code{what = "imputed"} - The original data set if it is complete; otherwise, this is
    the data set with missing values imputed by appropriate expectations.
  \item If \code{what = "complete"} - An \eqn{n} by \eqn{d} logical matrix indicating which cells have no missing values.
  \item If \code{what = "information"} - A data frame showing the number of clusters, final observed
    log-likelihood value, number of parameters, and desired information criteria.
}
}
\description{
Extract values from \code{MixtureMissing} objects or from outputs of
\link{select_mixture}.
}
\details{
Available information criteria include
\itemize{
  \item AIC - Akaike information criterion
  \item BIC - Bayesian information criterion
  \item KIC - Kullback information criterion
  \item KICc - Corrected Kullback information criterion
  \item AIC3 - Modified AIC
  \item CAIC - Bozdogan's consistent AIC
  \item AICc - Small-sample version of AIC
  \item ICL - Integrated Completed Likelihood criterion
  \item AWE - Approximate weight of evidence
  \item CLC - Classification likelihood criterion
}
}
\examples{

#++++ With no missing values ++++#

X <- iris[, 1:4]
mod <- MGHM(X, G = 2, model = 'GH', max_iter = 10)
extract(mod, what = "model")
extract(mod, what = "parameters")
extract(mod, what = "cluster")

#++++ With missing values ++++#

set.seed(123)
X <- hide_values(iris[, 1:4], n_cases = 20)
mod <- MGHM(X, G = 2, model = 'GH', max_iter = 10)
extract(mod, what = "outlier")
extract(mod, what = "missing")
extract(mod, what = "imputed")

}
